@@ -1,5 +1,5 @@
-import cube_face_vert_coord
-import cube_face_COM_coord
+from .cube_face_vert_coord import cube_face_vert_coord
+from .cube_face_COM_coord import cube_face_COM_coord
 
 
 def cube_face_COM_list_gen(radius: float):
